@@ -15,9 +15,9 @@ from .core import (
     _get_expected_groups,
     _validate_expected_groups,
     groupby_reduce,
-    rechunk_for_blockwise as rechunk_array_for_blockwise,
-    rechunk_for_cohorts as rechunk_array_for_cohorts,
 )
+from .core import rechunk_for_blockwise as rechunk_array_for_blockwise
+from .core import rechunk_for_cohorts as rechunk_array_for_cohorts
 from .xrutils import _contains_cftime_datetimes, _to_pytimedelta, datetime_to_numeric
 
 if TYPE_CHECKING:
@@ -223,7 +223,7 @@ def xarray_reduce(
         raise NotImplementedError("sort must be True for xarray_reduce")
 
     # eventually drop the variables we are grouping by
-    maybe_drop = set(b for b in by if isinstance(b, Hashable))
+    maybe_drop = {b for b in by if isinstance(b, Hashable)}
     unindexed_dims = tuple(
         b
         for b, isbin_ in zip(by, isbins)
@@ -313,7 +313,9 @@ def xarray_reduce(
     group_names: tuple[Any, ...] = ()
     group_sizes: dict[Any, int] = {}
     for idx, (b_, expect, isbin_) in enumerate(zip(by_da, expected_groups, isbins)):
-        group_name = b_.name if not isbin_ else f"{b_.name}_bins"
+        group_name = (
+            f"{b_.name}_bins" if isbin_ or isinstance(expect, pd.IntervalIndex) else b_.name
+        )
         group_names += (group_name,)
 
         if isbin_ and isinstance(expect, int):
@@ -341,11 +343,10 @@ def xarray_reduce(
             raise ValueError("expect_index cannot be None")
 
     def wrapper(array, *by, func, skipna, core_dims, **kwargs):
-
         array, *by = _broadcast_size_one_dims(array, *by, core_dims=core_dims)
 
         # Handle skipna here because I need to know dtype to make a good default choice.
-        # We cannnot handle this easily for xarray Datasets in xarray_reduce
+        # We cannot handle this easily for xarray Datasets in xarray_reduce
         if skipna and func in ["all", "any", "count"]:
             raise ValueError(f"skipna cannot be truthy for {func} reductions.")
 
@@ -431,7 +432,7 @@ def xarray_reduce(
 
     # restore non-dim coord variables without the core dimension
     # TODO: shouldn't apply_ufunc handle this?
-    for var in set(ds_broad.variables) - set(ds_broad.dims):
+    for var in set(ds_broad.variables) - set(ds_broad.xindexes) - set(ds_broad.dims):
         if all(d not in ds_broad[var].dims for d in dim_tuple):
             actual[var] = ds_broad[var]
 
@@ -509,7 +510,7 @@ def rechunk_for_cohorts(
         Labels at which we always start a new chunk. For
         the example ``labels`` array, this would be `1`.
     chunksize : int, optional
-        nominal chunk size. Chunk size is exceded when the label
+        nominal chunk size. Chunk size is exceeded when the label
         in ``force_new_chunk_at`` is less than ``chunksize//2`` elements away.
         If None, uses median chunksize along ``dim``.
 
@@ -583,7 +584,6 @@ def resample_reduce(
     keep_attrs: bool = True,
     **kwargs,
 ):
-
     warnings.warn(
         "flox.xarray.resample_reduce is now deprecated. Please use Xarray's resample method directly.",
         DeprecationWarning,
